@@ -12,6 +12,4 @@ class TestZBuildDeploy(src.jadecobra.tester.TestCase):
         self.assertEqual(
             jadecobra.__version__,
             src.jadecobra.__version__
-        )
-        os.remove('bob_function.zip')
-        os.remove('bob_layer.zip')
\ No newline at end of file
+        )
\ No newline at end of file
